%global _hardened_build 1

# Make reproducible builds possible
%global source_date_epoch_from_changelog 0
%global clamp_mtime_to_source_date_epoch 1
%global use_source_date_epoch_as_buildtime 1
%define _buildhost apkg

%{!?_syprefix: %define _syprefix /opt/symas }
%{!?_etcfix: %define _etcfix %{_syprefix}/etc }
%{!?_sylibdir: %define _sylibdir %{_syprefix}/lib }
%{!?_varfix: %define _varfix /var/symas }

%if 0%{?suse_version}
# We don't seem to have %{dist} in SUSEs, define our own
%{!?dist: %define dist .sles15 }
%endif

Summary: Symas's libevent build
Name: symas-libevent
Version: 2.1.12.1
Release: 1+znssl1%{?dist}
License: BSD
Source: %{name}-v%{version}.tar.xz

URL: https://libevent.org/
VCS: https://git.symas.net/symas-public/libevent.git

# Apparently distro setup should fill this in, but can't see where,
# Fake ours from dist and strip the leading dot
Distribution: %(echo %{?dist} | tr -d .)

AutoReqProv: no
# BuildRequires one at a time, microdnf doesn't support comma separated dependencies
BuildRequires: symas-buildtools >= 1.0.4
%if 0%{?suse_version}
BuildRequires: libopenssl-devel
%else
BuildRequires: openssl-devel
%endif
BuildRequires: pkgconfig
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: make
BuildRequires: libtool
BuildRequires: python3-devel
%if 0%{?suse_version}
BuildRequires: python3-tools
%endif
Requires: symas-libevent-libs = %{version}-%{release}

%description
The Symas libevent build

%prep
%setup -qn %{name}-v%{version}
%if 0%{?suse_version}
%{__python3} /usr/share/doc/packages/python3-core/Tools/scripts/pathfix.py -i %{__python3} -pn test/check-dumpevents.py event_rpcgen.py
%else
pathfix.py -i %{__python3} -pn test/check-dumpevents.py event_rpcgen.py
%endif

%build
autoreconf -f -i
export PKG_CONFIG_PATH=%{_sylibdir}/pkgconfig
LDFLAGS="-Wl,-rpath,%{_sylibdir}"; export LDFLAGS; \
CFLAGS="-O2 -g"; export CFLAGS; \
./configure --prefix=%{_syprefix} --disable-static
make

%check
make test

%install
make install DESTDIR=${RPM_BUILD_ROOT}
rm -rf %{buildroot}%{_sylibdir}/*.la
rm -rf %{buildroot}%{_syprefix}/bin/event_rpcgen.py
mkdir -p %{buildroot}%{_syprefix}/share/doc/libevent
install -m 0644 ChangeLog %{buildroot}%{_syprefix}/share/doc/libevent/
install -m 0644 LICENSE %{buildroot}%{_syprefix}/share/doc/libevent/
install -m 0644 README.md %{buildroot}%{_syprefix}/share/doc/libevent/
#rpath in /opt/symas is expected, so treat it as warning, not error:
export QA_RPATHS=$(( 0x0001|0x0002 ))

%package libs
Summary: libevent Libaries
AutoReqProv: no
Requires: openssl

%description libs
The symas-libevent-libs package contains the libevent libraries

%package devel
Summary: libevent Development
AutoReqProv: no
Requires: symas-libevent-libs = %{version}-%{release}

%description devel
The symas-libevent-devel package contains the linking libraries and include files

%files libs
%defattr(-,root,root)
%{_sylibdir}/*.so.*
%{_syprefix}/share/doc/libevent

%files devel
%defattr(-,root,root)
%{_syprefix}/include
%{_sylibdir}/pkgconfig/*.pc
%{_sylibdir}/*.so

%changelog
* Mon Jun 02 2025 Symas Support <support@symas.com> - 2.1.12.1-1+znssl1
- Bump version
* Tue Apr 15 2025 Symas Support <support@symas.com> - 2.1.12.1-1+nssl1
- Use native OpenSSL
* Wed Jun 05 2024 Symas Support <support@symas.com> - 2.1.12.1-1
- Switch to apkg for packaging
- Fake new upstream version so we can unify with DEB builds
* Wed May 31 2023 Symas Support <support@symas.com> - 2.1.12-3
- Rebuilding with OpenSSL3 support v 2.1.12-3
* Tue Nov 16 2021 Symas Support <support@symas.com> - 2.1.12-2
- Package ChangeLog, LICENSE, and README.md
* Tue Apr 6 2021 Symas Support <support@symas.com> - 2.1.12-1
- initial packaging
